@@ -1,4 +1,4 @@
-#! /usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 # A simple script to test controls interactively.
 
 from plugin.Interface import Interface
@@ -10,11 +10,16 @@ import sys
 import os
 import code
 import __builtin__
+try:
+    from dbus.mainloop.glib import DBusGMainLoop
+except:
+    pass
+else:
+    DBusGMainLoop(set_as_default=True)
 
 if "." not in sys.path: sys.path.append(".")
 if HOME not in sys.path: sys.path.append(HOME)
 
-
 try:
     path = os.path.abspath(sys.argv[1])
     folder, base = os.path.split(path)
